Rogaland Fylkeskommune fargepalette for "continuous" data, basert på fargene dis, dag, profil, aften og natt. Brukes som scale_color_gradientn() fra ggplot2 og tar de samme parameterene for uten colors, som gis fra før.
scale_color_rogfk_c(...)En streng med hex-farge-coder fra mørk til lys/hvit blå.
ggplot2::ggplot(
data = penguins,
ggplot2::aes(x = bill_len, y = body_mass, color = flipper_len)
) +
ggplot2::geom_point() +
scale_color_rogfk_c()
#> Warning: Removed 2 rows containing missing values or values outside the scale range
#> (`geom_point()`).