Rogaland Fylkeskommune fargepalette for "continuous" data, basert på fargene dis, dag, profil, aften og natt. Brukes som scale_color_gradientn() fra ggplot2 og tar de samme parameterene for uten fill, som gis fra før.

scale_fill_rogfk_c(...)

Value

En streng med hex-farge-coder fra mørk til lys/hvit blå.

Examples

ggplot2::ggplot(data = penguins) +
  ggplot2::geom_col(
    ggplot2::aes(x = species, y = body_mass, fill = flipper_len)
  ) +
  scale_fill_rogfk_c()
#> Warning: Removed 2 rows containing missing values or values outside the scale range
#> (`geom_col()`).