A minimal ggplot theme that employs the golden ratio to great effect. Credit to Christopher Adolph (with help from Kai Ping Leung) for Faceting this theme (faculty.washington.edu/cadolph). Tweaked by Marius Swane Wishman.
rogfkBeautifully formatted plot
ggplot2::ggplot(data = penguins, ggplot2::aes(x = year, y = body_mass)) +
ggplot2::geom_point() +
rogfk
#> Warning: Removed 2 rows containing missing values or values outside the scale range
#> (`geom_point()`).